package main

import (
	"fmt"
	"os"

	"codeberg.org/woodpecker-plugins/plugin-docker-buildx/plugin"
	"github.com/joho/godotenv"
	"github.com/sirupsen/logrus"
	"github.com/urfave/cli/v2"

	"github.com/thegeeklab/drone-plugin-lib/v2/drone"
	"github.com/thegeeklab/drone-plugin-lib/v2/urfave"
)

var version = "unknown"

func main() {
	settings := &plugin.Settings{}

	if _, err := os.Stat("/run/drone/env"); err == nil {
		godotenv.Overload("/run/drone/env")
	}

	if envFile, set := os.LookupEnv("PLUGIN_ENV_FILE"); set {
		godotenv.Overload(envFile)
	}

	app := &cli.App{
		Name:    "docker-buildx",
		Usage:   "build docker container with DinD and buildx",
		Version: version,
		Flags:   append(settingsFlags(settings), urfave.Flags()...),
		Action:  run(settings),
	}

	if err := app.Run(os.Args); err != nil {
		logrus.Fatal(err)
	}
}

func run(settings *plugin.Settings) cli.ActionFunc {
	return func(ctx *cli.Context) error {
		urfave.LoggingFromContext(ctx)

		cacheFrom, ok := ctx.Generic("cache-from").(*drone.StringSliceFlag)
		if !ok {
			return fmt.Errorf("failed to read cache-from input")
		}

		settings.Build.CacheFrom = cacheFrom.Get()

		plugin := plugin.New(
			*settings,
			urfave.PipelineFromContext(ctx),
			urfave.NetworkFromContext(ctx),
		)

		if err := plugin.Validate(); err != nil {
			return fmt.Errorf("validation failed: %w", err)
		}

		if err := plugin.Execute(); err != nil {
			return fmt.Errorf("execution failed: %w", err)
		}

		return nil
	}
}
